C-----------------------------------------------------------------------
      SUBROUTINE BAOPENR(LU,CFN,IRET)
C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C
C SUBPROGRAM: BAOPENR        BYTE-ADDRESSABLE OPEN FOR READ-ONLY
C   PRGMMR: IREDELL          ORG: W/NMC23     DATE: 94-04-01
C
C ABSTRACT: OPEN A FILE TO BE ACCESSED BY BAREAD ONLY
C
C PROGRAM HISTORY LOG:
C   96-10-01  IREDELL     STANDARD F77 VERSION
C
C USAGE:    CALL BAOPENR(LU,CFN,IRET)
C   INPUT ARGUMENTS:
C     LU           INTEGER UNIT TO OPEN
C     CFN          CHARACTER (*) FILE NAME TO OPEN
C   OUTPUT ARGUMENTS:
C     IRET         INTEGER RETURN CODE (0 IF SUCCESSFUL)
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN 77
C
C$$$
      CHARACTER CFN*(*)
      CHARACTER CFORM*11
      PARAMETER(CFORM='UNFORMATTED')
      OPEN(LU,FILE=CFN,IOSTAT=IRET,ACCESS='DIRECT',RECL=1,FORM=CFORM,
     &     STATUS='OLD')
      END
